Audio (Signal, TimeData, FrequencyData)
---------------------------------------
.. automodule:: spharpy.classes.audio

**Classes:**

.. autosummary::

   SphericalHarmonicFrequencyData
   SphericalHarmonicTimeData
   SphericalHarmonicSignal

.. autoclass:: spharpy.SphericalHarmonicSignal
   :members:
   :undoc-members:
   :inherited-members:

.. autoclass:: spharpy.SphericalHarmonicTimeData
   :members:
   :undoc-members:
   :inherited-members:

.. autoclass:: spharpy.SphericalHarmonicFrequencyData
   :members:
   :undoc-members:
   :inherited-members:
